ExpiresAfter

Struct ExpiresAfter 

pub struct ExpiresAfter {
    pub anchor: Option<Anchor>,
    pub minutes: Option<i64>,
}
The container will expire after this time period. The anchor is the reference point for the expiration. The minutes is the number of minutes after the anchor before the container expires.

Fields

anchor: Option<Anchor>

The reference point for the expiration.

minutes: Option<i64>

The number of minutes after the anchor before the container expires.

Implementations

Source

impl ExpiresAfter

pub fn builder() -> ExpiresAfterBuilder<((), ())>

Create a builder for building ExpiresAfter. On the builder, call .anchor(...)(optional), .minutes(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of ExpiresAfter.