pub struct FunctionObject {
pub description: Option<String>,
pub name: String,
pub parameters: Option<FunctionParameters>,
pub strict: Option<bool>,
}Fields
description: Option<String>A description of what the function does, used by the model to choose when and how to call the function.
name: StringThe name of the function to be called. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.
parameters: Option<FunctionParameters>strict: Option<bool>Whether to enable strict schema adherence when generating the function call. If set to true, the model will follow the exact schema defined in the parameters field. Only a subset of JSON Schema is supported when strict is true. Learn more about Structured Outputs in the function calling guide.
Implementations
Sourceimpl FunctionObject
impl FunctionObject
Sourcepub fn builder() -> FunctionObjectBuilder<((), (), (), ())>
pub fn builder() -> FunctionObjectBuilder<((), (), (), ())>
Create a builder for building FunctionObject.
On the builder, call .description(...)(optional), .name(...), .parameters(...)(optional), .strict(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of FunctionObject.