pub struct VectorStoreFileObject {
pub id: String,
pub usage_bytes: i64,
pub created_at: i64,
pub vector_store_id: String,
pub status: Status,
pub last_error: Option<LastError>,
pub chunking_strategy: Option<ChunkingStrategyResponse>,
pub attributes: Option<VectorStoreFileAttributes>,
}Expand description
A list of files attached to a vector store.
Fields
id: StringThe identifier, which can be referenced in API endpoints.
usage_bytes: i64The total vector store usage in bytes. Note that this may be different from the original file size.
created_at: i64The Unix timestamp (in seconds) for when the vector store file was created.
vector_store_id: StringThe ID of the vector store that the File is attached to.
status: StatusThe status of the vector store file, which can be either in_progress, completed, cancelled, or failed. The status completed indicates that the vector store file is ready for use.
last_error: Option<LastError>The last error associated with this vector store file. Will be null if there are no errors.
chunking_strategy: Option<ChunkingStrategyResponse>attributes: Option<VectorStoreFileAttributes>Implementations
Sourceimpl VectorStoreFileObject
impl VectorStoreFileObject
Sourcepub fn builder() -> VectorStoreFileObjectBuilder<((), (), (), (), (), (), (), ())>
pub fn builder() -> VectorStoreFileObjectBuilder<((), (), (), (), (), (), (), ())>
Create a builder for building VectorStoreFileObject.
On the builder, call .id(...), .usage_bytes(...), .created_at(...), .vector_store_id(...), .status(...), .last_error(...)(optional), .chunking_strategy(...)(optional), .attributes(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of VectorStoreFileObject.