pub struct VectorStoreObject {
pub id: String,
pub created_at: i64,
pub name: String,
pub usage_bytes: i64,
pub file_counts: FileCounts,
pub status: Status,
pub expires_after: Option<VectorStoreExpirationAfter>,
pub expires_at: Option<i64>,
pub last_active_at: Option<i64>,
pub metadata: Option<Metadata>,
}Expand description
A vector store is a collection of processed files can be used by the file_search tool.
Fields
id: StringThe identifier, which can be referenced in API endpoints.
created_at: i64The Unix timestamp (in seconds) for when the vector store was created.
name: StringThe name of the vector store.
usage_bytes: i64The total number of bytes used by the files in the vector store.
file_counts: FileCountsstatus: StatusThe status of the vector store, which can be either expired, in_progress, or completed. A status of completed indicates that the vector store is ready for use.
expires_after: Option<VectorStoreExpirationAfter>expires_at: Option<i64>The Unix timestamp (in seconds) for when the vector store will expire.
last_active_at: Option<i64>The Unix timestamp (in seconds) for when the vector store was last active.
metadata: Option<Metadata>Implementations
Sourceimpl VectorStoreObject
impl VectorStoreObject
Sourcepub fn builder() -> VectorStoreObjectBuilder<((), (), (), (), (), (), (), (), (), ())>
pub fn builder() -> VectorStoreObjectBuilder<((), (), (), (), (), (), (), (), (), ())>
Create a builder for building VectorStoreObject.
On the builder, call .id(...), .created_at(...), .name(...), .usage_bytes(...), .file_counts(...), .status(...), .expires_after(...)(optional), .expires_at(...)(optional), .last_active_at(...)(optional), .metadata(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of VectorStoreObject.