pub type InputMessageContentList = Vec<InputContent>;Expand description
A list of one or many input items to the model, containing different content types.
Aliased Type
pub struct InputMessageContentList { /* private fields */ }pub type InputMessageContentList = Vec<InputContent>;A list of one or many input items to the model, containing different content types.
pub struct InputMessageContentList { /* private fields */ }